@@ -1,5 +1,4 @@
 from __future__ import annotations
-from asyncio.futures import Future
 
 import sys
 from os import environ, execl
@@ -7,9 +6,11 @@ from os import environ, execl
 from asyncio import (
     wait_for,
     new_event_loop,
-    AbstractEventLoop,
     iscoroutinefunction,
-    run_coroutine_threadsafe
+    run_coroutine_threadsafe,
+    AbstractEventLoop,
+    TimeoutError,
+    Future
 )
 from dotenv import load_dotenv
 from typing import (
@@ -43,7 +44,7 @@ Coro_return_chat_message = Callable[[], Coroutine[Message.from_ws, None, None]]
 Coro_return_Any = Callable[[], Coroutine[Any, None, None]]
 Coro_return_None = Callable[[], Coroutine[None, None, None]]
 
-version = '0.0.40'
+version = '0.0.45'
 
 class Bot:
     __slots__ = (
@@ -198,6 +199,7 @@ class Bot:
         files: str     | None = None,
         type_: int     | None = 0,
         embed: 'Embed' | None = None, # type: ignore
+        reply: str     | None = None,
         com:   str     | None = None,
         chat:  str     | None = None
     ) -> Awaitable[list[dict[str, Any]]]:
@@ -207,6 +209,7 @@ class Bot:
             files = files,
             type_ = type_,
             embed = embed,
+            reply = reply,
             com   = com,
             chat  = chat
         )
