@@ -5,4 +5,6 @@ class CommandIsntAsync(Exception): pass
 class EventIsntAsync(Exception): pass
 class InvalidChatChoice(Exception): pass
 class InvalidEvent(Exception): pass
-class InvalidFileType(Exception): pass
\ No newline at end of file
+class InvalidFileType(Exception): pass
+class InvalidReturn(Exception): pass
+class AminoSays(Exception): pass
\ No newline at end of file
