@@ -1,8 +1,13 @@
 from __future__ import annotations
-from re import M
 
 from uuid import uuid4
-from typing import Any, Awaitable, Callable, Literal, NoReturn, Dict
+from typing import (
+    Any, 
+    Callable, 
+    Literal, 
+    NoReturn, 
+    Dict
+)
 from pathlib import Path
 from asyncio import gather
 from platform import system
@@ -106,7 +111,7 @@ async def _req(
     data:       dict[str, Any] | None = None,
     need_dumps: bool                  = True,
     return_:    str                   = 'json',
-) -> Awaitable[Req_json | str | bytes] | ClientResponse:
+) -> Req_json | str | bytes | ClientResponse:
 
     async with request(
         method           = method,
@@ -128,6 +133,20 @@ async def _req(
         raise InvalidReturn(return_)
 
 
+class _Reply:
+    __slots__ = (
+        'icon',
+        'id',
+        'nickname',
+        'uid'
+    )
+
+    def __init__(self, ext):
+        self.icon = ext['replyMessage']['author']['icon']
+        self.id = ext['replyMessageId']
+        self.nickname = ext['replyMessage']['author']['nickname']
+        self.uid = ext['replyMessage']['author']['uid']
+
 class Message:
     __slots__ = (
         'author',
@@ -137,6 +156,7 @@ class Message:
         'file_link',
         'icon',
         'id',
+        'reply',
         'media_type',
         'mentioned_users',
         'nickname',
@@ -160,8 +180,9 @@ class Message:
 
         self.icon:            str | None       = get_value(_cm, 'author', 'icon')
         self.id:              str | None       = get_value(_cm, 'messageId')
+        self.reply:           _Reply           = _Reply(self.extensions) if 'replyMessage' in self.extensions else None
         self.media_type:      str | None       = get_value(_cm, 'mediaType')
-        self.mentioned_users: list[str] | None = [u.uid for u in get_value(self.extensions, 'mentionedArray') or []]
+        self.mentioned_users: list[str] | None = [u['uid'] for u in get_value(self.extensions, 'mentionedArray') or []]
 
         self.nickname: str | None = get_value(_cm, 'author', 'nickname')
         self.text:     str | None = get_value(_cm, 'content')
@@ -183,8 +204,13 @@ class Message:
         return self
 
     class _CreateData:
-        async def msg(type, msgs):
-            return [{'type': type, 'content': i} for i in msgs]
+        async def msg(type, msgs, reply):
+            return [
+                {'type': type, 'content': i, 'replyMessageId': reply}
+                if reply
+                else {'type': type, 'content': i}
+                for i in msgs
+            ]
 
         async def file(files):
             return [await FILE.process(i) for i in files]
@@ -207,11 +233,12 @@ class Message:
     async def send(
         self,
         *msgs: list[str],
-        files: str | list[str] | None = None,
-        type_: int | None             = 0,
-        embed: Embed | None           = None,
-        com:   str | None             = None,
-        chat:  str | None             = None,
+        files: str   | list[str] | None = None,
+        type_: int   | None             = 0,
+        embed: Embed | None             = None,
+        reply: str   | None             = None,
+        com:   str   | None             = None,
+        chat:  str   | None             = None,
     ) -> list[Req_json]:
 
         com = com or actual_com
@@ -219,7 +246,7 @@ class Message:
         files = [files] if files and not isinstance(files, (tuple, list)) else files
 
         if msgs:
-            data = await self._CreateData.msg(type_, msgs)
+            data = await self._CreateData.msg(type_, msgs, reply)
         elif files:
             data = await self._CreateData.file(files)
         else:
@@ -281,28 +308,28 @@ class User:
 
     def __init__(self, j: Req_json | None = None):
         if j:
-            self.bio             = get_value(j, 'content')
-            self.blogs_count     = get_value(j, 'blogsCount')
-            self.com             = get_value(j, 'ndcId', convert=str)
-            self.comments_count  = get_value(j, 'commentsCount')
-            self.created_time    = get_value(j, 'createdTime')
-            self.followers_count = get_value(j, 'membersCount')
-            self.following_count = get_value(j, 'joinedCount')
-            self.im_following    = get_value(j, 'followingStatus') == 1
-            self.level           = get_value(j, 'level')
-            self.nickname        = get_value(j, 'nickname')
-            self.posts_count     = get_value(j, 'postsCount')
-            self.id              = get_value(j, 'uid')
-            self.reputation      = get_value(j, 'reputation')
-            self.role            = {0: 'member', 101: 'curator', 100: 'leader', 102: 'leader-agent'}[j['role']]
-            self.visitors_count  = get_value(j, 'visitoresCount')
+            self.bio:             str | None = get_value(j, 'content')
+            self.blogs_count:     int | None = get_value(j, 'blogsCount')
+            self.com:             str | None = get_value(j, 'ndcId', convert=str)
+            self.comments_count:  int | None = get_value(j, 'commentsCount')
+            self.created_time:    int | None = int(datetime.fromisoformat(j['createdTime'][:-1]).timestamp()) if j['createdTime'] else None
+            self.followers_count: str | None = get_value(j, 'membersCount')
+            self.following_count: str | None = get_value(j, 'joinedCount')
+            self.im_following:    bool       = get_value(j, 'followingStatus') == 1
+            self.level:           str | None = get_value(j, 'level')
+            self.nickname:        str | None = get_value(j, 'nickname')
+            self.posts_count:     int | None = get_value(j, 'postsCount')
+            self.id:              str | None = get_value(j, 'uid')
+            self.reputation:      int | None = get_value(j, 'reputation')
+            self.role:            str | None = {0: 'member', 101: 'curator', 100: 'leader', 102: 'leader-agent'}[j['role']]
+            self.visitors_count:  int | None = get_value(j, 'visitoresCount')
 
     @classmethod
     async def search(
         cls,
         uids: str | list[str],
         com:  str | None = None
-    ) -> Awaitable[list[User]]:
+    ) -> list[User]:
 
         com = com or actual_com
         uids = [uids] if not isinstance(uids, (list, tuple)) else uids
@@ -320,7 +347,8 @@ class User:
         *,
         reason: str,
         com:    str | None = None
-    ):
+    ) -> Req_json:
+
         com = com or actual_com
         if words(reason) < 3:
             raise SmallReasonForBan('Put a reason with at least three words')
@@ -337,7 +365,8 @@ class User:
         *,
         reason: str        = '',
         com:    str | None = None
-    ):
+    ) -> Req_json:
+
         com = com or actual_com
 
         return await _req(
@@ -417,7 +446,7 @@ class Chat:
         'bg',
         'can_send_coins',
         'co_hosts',
-        'created_in',
+        'created_time',
         'adm',
         'extensions',
         'icon',
@@ -433,31 +462,32 @@ class Chat:
 
     def __init__(self, j=None):
         if j:
-            t = get_value(j, 'thread') or j
-            self.extensions         = get_value(t, 'extensions')
+            t:                       Dict[str, Any] | None = get_value(j, 'thread') or j
+            self.extensions:         Dict[str, Any] | None = get_value(t, 'extensions')
 
-            self.announcement       = get_value(self.extensions, 'announcement') or ''
-            self.bg                 = get_value(self.extensions, 'bm')[1] if 'bm' in self.extensions else None
-            self.can_send_coins     = get_value(t, 'tipInfo', 'tippable')
-            self.co_hosts           = get_value(self.extensions, 'coHost') or []
-            self.created_in         = int(datetime.fromisoformat(t['createdTime'][:-1]).timestamp()) if t['createdTime'] else None
-            self.adm                = get_value(t, 'author', 'uid')
-            self.icon               = get_value(t, 'icon')
-            self.id                 = get_value(t, 'threadId')
-            self.is_pinned          = get_value(t, 'isPinned')
-            self.is_private         = get_value(t, 'membersQuota') == 2
-            self.members_can_invite = get_value(t, 'membersCanInvite') or True
-            self.name               = get_value(t, 'title')
-            self.only_fans          = get_value(self.extensions, 'fansOnly')
-            self.only_view          = get_value(self.extensions, 'viewOnly') or False
-            self.text               = get_value(t, 'content') or ''
+            self.announcement:       str | None = get_value(self.extensions, 'announcement') or ''
+            self.bg:                 str | None = get_value(self.extensions, 'bm')[1] if 'bm' in self.extensions else None
+            self.can_send_coins:     bool       = get_value(t, 'tipInfo', 'tippable')
+            self.co_hosts:           list[str]  = get_value(self.extensions, 'coHost') or []
+            self.created_time:       int | None = int(datetime.fromisoformat(t['createdTime'][:-1]).timestamp()) if t['createdTime'] else None
+            self.adm:                str | None = get_value(t, 'author', 'uid')
+            self.icon:               str | None = get_value(t, 'icon')
+            self.id:                 str | None = get_value(t, 'threadId')
+            self.is_pinned:          bool       = get_value(t, 'isPinned')
+            self.is_private:         bool       = get_value(t, 'membersQuota') == 2
+            self.members_can_invite: bool       = get_value(t, 'membersCanInvite') or True
+            self.name:               str | None = get_value(t, 'title')
+            self.only_fans:          bool       = get_value(self.extensions, 'fansOnly')
+            self.only_view:          bool       = get_value(self.extensions, 'viewOnly') or False
+            self.text:               str | None = get_value(t, 'content') or ''
 
     @classmethod
     async def search(
         cls,
         com:  str | None = None,
         chat: str | None = None
-    ):
+    ) -> Chat:
+
         com = com or actual_com
         chat = chat or actual_chat
 
